import 'dart:convert';
import 'package:loyalty_foop/bloc/common_widgets/rewards_widget.dart';
import 'package:loyalty_foop/bloc/cubits/cubit_main.dart';
import 'package:loyalty_foop/bloc/rewards_module/pages/postcreatepage.dart';
import 'package:loyalty_foop/bloc/states/main_state.dart';
import 'package:loyalty_foop/bloc/states/states.dart';
import 'package:loyalty_foop/models/postcreate.dart';
import 'package:loyalty_foop/models/postlist.dart';
import 'package:loyalty_foop/models/welcomeMessagesListResponse.dart';
import 'package:loyalty_foop/utils/basicInfo.dart';
import 'package:loyalty_foop/utils/colors.dart';
import 'package:loyalty_foop/utils/custom_app_bar.dart';
import 'package:loyalty_foop/utils/empty_widget.dart';
import 'package:loyalty_foop/utils/hexColors.dart';
import 'package:loyalty_foop/utils/localization.dart';
import 'package:loyalty_foop/utils/locator.dart';
import 'package:loyalty_foop/utils/text_styling.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:shared_preferences/shared_preferences.dart';

import 'loyality_type_page.dart';

class RewardsListPage extends StatefulWidget {
  final String type;
  final String messageTo;

  RewardsListPage({required this.type, required this.messageTo});

  @override
  State<StatefulWidget> createState() => RewardsListPageState();
}

class RewardsListPageState extends State<RewardsListPage> {
  SharedPreferences? prefs = locator<SharedPreferences>();
  BasicInfo? basicInfo = locator<BasicInfo>();

  @override
  void initState() {

    WidgetsBinding.instance!.addPostFrameCallback((_) {
      fetchData();
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: appAppBar().getCustomAppBar(context,
          appBarTitle:

          AppLocalizations.of(context)!
              .translate("manage_lo_prog"),
          actions: [
            IconButton(
                onPressed: () {
                  openDesiredPage();
                },
                icon: Icon(
                  Icons.add_circle,
                  color: HexColor(AppColors.blueApp),
                ))
          ], onBackButtonPress: () {
            Navigator.pop(context);
          }),
      body: BlocBuilder<CubitMain, MainState>(
          builder: (context, state) => state is LoadingState
              ? const Center(child: CircularProgressIndicator())
              : state is Loaded
              ? SafeArea(
            child: Container(
              child: ListView.builder(
                  itemCount: state.list.length,
                  itemBuilder: (ctx, position) {
                    return getPostWidget(ctx, state.list[position]);
                  }),
            ),
          )
              : state is Empty
              ? Center(
            child: Center(
                child: EmptyWidget(AppLocalizations.of(context)!
                    .translate("no_data"))),
          )
              : Center(
            child: Center(
                child: EmptyWidget(AppLocalizations.of(context)!
                    .translate("no_data"))),
          )),
    );
  }

  Widget getPostWidget(BuildContext ctx, WelcomeMessageItem item) {
    item.avatar = basicInfo!.userImage;
    item.businessId = basicInfo!.businessId;
    item.name = basicInfo!.userName;

    if (widget.type == "chat") {

      if(item.messageDetails?.messageAttachment!=null && item.messageDetails!.messageAttachment!.isNotEmpty)
      {
        Media media=Media();
        media.mediaUrl=item.messageDetails?.messageAttachment??"";
        media.mediaThumbnailUrl=item.messageDetails?.messageAttachmentThumbnail??"";
        media.mediaType=item.messageDetails?.messageAttachmentType??"";
        item.messageDetails?.mediaDetails=[media];
      }
      else item.messageDetails?.mediaDetails=[];

      ContentMeta contentMeta =ContentMeta();
      contentMeta.title=null;
      contentMeta.meta=item.messageDetails?.message??"";;
      item.messageDetails?.contentMeta=contentMeta;
    }

    return RewardsWidget(
      item: item,
      deleteCallBack: (id) {
        createPost(null, id, "deleted");
      },
      editCallBack: (item) {
        Navigator.of(context)
            .push(MaterialPageRoute(
            builder: (context) => PostCreatePage(
              type: "feed",
              isWelcomeMessage: true,
              mediaFromEdit: item?.messageDetails?.mediaDetails,
              postId: item?.id,
              contentData: item?.messageDetails?.contentMeta?.meta,
              titleLesson: item?.messageDetails?.contentMeta?.title,
              isEdit: true,
            )))
            .then((value) => {
          if (value != null && value['postData'] != null)
            createPost(value['postData'], item?.id, "active")
        })
           ;
      },
    );
  }

  void openDesiredPage() {
   Navigator.push(context,
        MaterialPageRoute(builder: (BuildContext context) {
          return LoyaltyTypePage(

          );
        })).then((value) => {
      if (value != null && value['postData'] != null)
        createPost(null, null, "active")
    });
  }

  void fetchData() {
    var body = jsonEncode({
      "business_id": basicInfo!.businessId,
      "applicable_to": widget.messageTo,
      "message_type": widget.type
    });
    context.read<CubitMain>().getWelcomeMessagesData(body, context);
  }

  void createPost(PostCreatePayload? payload, int? id, String status) {
    var bodyRefresh = jsonEncode({
      "business_id": basicInfo!.businessId,
      "applicable_to": widget.messageTo,
      "message_type": widget.type
    });
    var body = jsonEncode({
      "id": id,
      "status": status,
      "business_id": basicInfo!.businessId,
      "applicable_to": widget.messageTo,
      "message_type": widget.type,
      "message_details": {
        "media_details": payload?.mediaDetails,
        "content_meta": payload?.contentMeta
      }
    });
    context.read<CubitMain>().createPost(body, bodyRefresh, context);
  }
}
